This is a tool for experimenting with network layouts, powered by the d3-force API. You may find it useful if you, like me, feel that Gephi is too heavy-weight, networkx is too ugly and writing d3 code everytime you want to make a pretty network is too much work.
To start using it slide things left and right in the controls menu. You can import your own data by linking to it or uploading it, and once you are happy with how it looks you can download it.
Data should be either JSON or CSV, and there are some simple rules for formatting. I suggest you mimic the formatting of these example files (JSON, CSV). Note that 'size' attribute and 'weight' column/attribute are optional in either format.
Most of the attributes in the control panel are self-explanatory. The 'Physics' attributes relate to variables in the d3-force API, while the '... scaling exponent' attributes control the power to which nodes sizes and link weights are raised before rendering. For example, if 'node scaling exponent' is 0.5, the size of rendered nodes is the half power (which is the square root) of the 'size' attribute given by the input, such that node area is proportional to 'size' attribute. If 1, node radius is propotional with 'size'. If negative, nodes with a large 'size' attribute become small and vice versa. But for simplicity just think of the exponent as a parameter for tuning the "unevenness" of node sizes or link weights.
Parameter presets can be saved, exported and reset. This all happens in the top bar of the control panel. It's useful if you have found a style you like and want save it for later. What you can do then is click 'New' and give that parameter preset a name. When you load a new network (or close the browser and come back) your browser will remember those values. If you want to export your preset as JSON, you can click the ⚙icon.
Made by Ulf Aslak. Code available on Github. If you find any bugs, or have suggestions for improvements or further developments, please get in touch.